
Vertical Solutions
==================

Perpetual provides specialized modules and configurations for specific industry verticals and causal inference tasks.

.. toctree::
   :maxdepth: 1
   :caption: Verticals

   uplift
   iv
   risk
